'use strict';

exports.__esModule = true;

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

exports.default = {
  propTypes: {
    className: _propTypes2.default.string,
    id: _propTypes2.default.string,
    label: _propTypes2.default.string,
    name: _propTypes2.default.string,
    onChange: _propTypes2.default.func,
    required: _propTypes2.default.bool,
    value: _propTypes2.default.string,
    wrapperClassName: _propTypes2.default.string
  },

  /**
   * Patch formsy to support defaultValue.
   */
  componentWillMount: function componentWillMount() {
    var value = typeof this.props.defaultValue === 'undefined' ? this.props.value : this.props.defaultValue;

    this.setState({
      _value: value,
      _pristineValue: value
    });
  },
  getDefaultProps: function getDefaultProps() {
    return {
      className: 'form-control'
    };
  },


  /**
   * Get an array of options from props.
   *
   * @returns {{value: string, label: string}[]}
   */
  getOptions: function getOptions() {
    var options = this.props.options;


    if (!Array.isArray(options)) return Object.keys(options).map(function (key) {
      return { value: String(key), label: options[key] };
    });

    return options.map(function (entry) {
      return typeof entry === 'string' ? { value: entry, label: entry } : entry;
    });
  },


  // from https://github.com/twisty/formsy-react-components/
  hashString: function hashString(string) {
    var hash = 0;
    for (var i = 0; i < string.length; i++) {
      hash = (hash << 5) - hash + string.charCodeAt(i) & 0xffffffff;
    }
    return hash;
  },


  // from https://github.com/twisty/formsy-react-components/
  getId: function getId() {
    var _props = this.props,
        leftAddon = _props.leftAddon,
        rightAddon = _props.rightAddon,
        hashProps = _objectWithoutProperties(_props, ['leftAddon', 'rightAddon']);

    return this.props.id || this.props.name.split('[').join('_').replace(']', '') + this.hashString(JSON.stringify(hashProps));
  },
  getControlProps: function getControlProps() {
    var _props2 = this.props,
        className = _props2.className,
        name = _props2.name,
        disabled = _props2.disabled;

    var value = this.getValue();
    return { className: className, id: this.getId(), name: name, value: value, disabled: disabled };
  },
  getWrapperProps: function getWrapperProps() {
    var _props3 = this.props,
        label = _props3.label,
        wrapperClassName = _props3.wrapperClassName;

    var hasError = !this.isValid() && !this.isPristine();
    return { componentId: this.getId(), className: wrapperClassName, hasError: hasError, label: label };
  },
  changeValue: function changeValue(nextValue) {
    var prevValue = this.getValue();

    if (String(prevValue) === String(nextValue)) return;

    this.setValue(nextValue);

    if (this.props.onChange) this.props.onChange(nextValue);
  }
};